# -*- coding: utf-8 -*-
from autodiscover import autodiscover

"""
Django Addons app automatically looks for handlers.py in addon folders,
loads the module and calls connect() on it to connect signal handlers.
Similar operation is performed on notifications.py to load
notification types for each addon.

Copyright (C) 2010 by Indifex (www.indifex.com), see AUTHORS.
License: BSD, see LICENSE for details.

For further information visit http://code.indifex.com/django-addons
"""

# DONT PUT THIS TO __init__.py!
autodiscover()



# -*- coding: utf-8 -*-

"""
Copyright (C) 2010 by Indifex (www.indifex.com), see AUTHORS.
License: BSD, see LICENSE for details.

For further information visit http://code.indifex.com/django-addons
"""

import sys, traceback
from django.conf import settings

def autodiscover_handlers():
    """
    Register signal handlers from each addon.
    """
    for addon in settings.ADDONS:
        fullname = "%s.handlers" % addon
        try:
            __import__(fullname)
        except ImportError, err:
            if str(err) != "No module named handlers":
                traceback.print_exc()
                raise err

        if fullname in sys.modules:
            handlers = sys.modules[fullname]
            handlers.connect()

def autodiscover_notifications():
    """
    Register notifications from each addon.
    TODO: Implement this with signals. Requires changes in django-notifications upstream.
    """
    for addon in settings.ADDONS:
        fullname = "%s.notifications" % addon
        try:
            __import__(fullname)
        except ImportError:
            pass

def autodiscover():
    autodiscover_notifications()
    autodiscover_handlers()



# -*- coding: utf-8 -*-

"""
This is django_addons.urls module, it loads URLconf of
each addon.

In main urls you should have something like:

  urlpatterns += patterns('', (r'', include('django_addons.urls')))


Copyright (C) 2010 by Indifex (www.indifex.com), see AUTHORS.
License: BSD, see LICENSE for details.

For further information visit http://code.indifex.com/django-addons

"""

import os
from django.conf.urls.defaults import *
from django.conf import settings
from views import addons_view

urlpatterns = patterns('')

if settings.DEBUG:
    urlpatterns += patterns('', url(r'^addons/$', addons_view))

for addon in settings.ADDONS:
    addon_dir = None
    for ADDONS_ROOT in settings.ADDONS_ROOTS:
        addon_dir = "%s/%s" % (ADDONS_ROOT, addon)
        if os.path.exists(addon_dir):
            break

    filename = "%s/urls.py" % (addon_dir)
    fullname = "%s.urls" % addon
    if os.path.exists(filename):
        urlpatterns += patterns('',
            url(r'', include(fullname)),
        )



# -*- coding: utf-8 -*-

"""
Copyright (C) 2010 by Indifex (www.indifex.com), see AUTHORS.
License: BSD, see LICENSE for details.

For further information visit http://code.indifex.com/django-addons
"""

import os
import sys

VERSION = (0, 6, 6, 'final')

def get_version():
    version = '%s.%s' % (VERSION[0], VERSION[1])
    if VERSION[2]:
        version = '%s.%s' % (version, VERSION[2])
    if VERSION[3] != 'final':
        version = '%s %s' % (version, VERSION[3])
    return version

def dependency_found(addon):
    from django.conf import settings
    return addon in ( \
        getattr(settings, "ADDONS", []) + 
        getattr(settings, "ADDONS_PROVIDED", []))

def get_meta(name):
    # Load metainformation
    try:
        mod = None
        __import__(name)
        mod = sys.modules[name]
    except Exception, e:
        print e
        pass
    return getattr(mod, 'Meta', None)






# -*- coding: utf-8 -*-
from django.db.models.signals import *
"""

This is a simple addon which just dumps information 
about signals passed in your Django project.

Sample output:

Example addon received SIGNAL:
              sender = <class 'projects.models.Project'>,
                 raw = False,
            instance = some-cool-project,
             created = False

"""

def handler(sender, signal=None, **kwargs):
    s = []
    for key, value in (("sender", sender),):
        s += ["\t% 12s = %s" % (key,value)]
    for key, value in kwargs.iteritems():
        if key != "request":
            s += ["\t% 12s = %s" % (key,value)]
        else:
           s += ["\t% 12s = %s" % ("request","<skipped>")]
           s += ["\t% 12s = %s" % ("request.POST",value.POST)]
           s += ["\t% 12s = %s" % ("request.GET", value.GET)]
    print "Example addon received SIGNAL:\n%s" % (',\n'.join(s))

# Django signals:
for signal in [
    post_save,
    post_delete,]:
    signal.connect(handler)




# -*- coding: utf-8 -*-
from codecs import BOM
import glob
import os
from setuptools import setup, find_packages
from django_addons import get_version

readme_file = open(u'README')
long_description = readme_file.read()
readme_file.close()
if long_description.startswith(BOM):
    long_description = long_description.lstrip(BOM)
long_description = long_description.decode('utf-8')


setup(
    name='django-addons',
    version=get_version().replace(' ', '-'),
    description='Addon framework for Django',
    long_description=long_description,
    author='Dimitris Glezos',
    author_email='glezos@indifex.com',
    url='http://code.indifex.com/django-addons/',
    download_url='http://code.indifex.com/django-addons/downloads/',
    license = 'BSD',
    zip_safe = False,
    packages=find_packages(),
    classifiers=['Development Status :: 4 - Beta',
                'Environment :: Web Environment',
                'Framework :: Django',
                'Intended Audience :: Developers',
                'License :: OSI Approved :: BSD License',
                'Operating System :: OS Independent',
                'Programming Language :: Python',
                'Topic :: Software Development :: Libraries :: Python Modules',
                'Topic :: Utilities'],
    setup_requires = [
        "Django >= 1.2.3",
    ],
    install_requires = [
        "Django >= 1.2.3",
    ],
    package_data = {
        'django_addons': [
            'templates/*.html',
        ]
    },
)



# -*- coding: utf-8 -*-

"""
Copyright (C) 2010 by Indifex (www.indifex.com), see AUTHORS.
License: BSD, see LICENSE for details.

For further information visit http://code.indifex.com/django-addons
"""

from django.db import models
from django.conf import settings
#from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response #, get_object_or_404
from django.template import RequestContext

from django_addons import get_meta

def addons_view(request):
    addons = {}
    for addon in settings.ADDONS:
        print addon
        addons[addon] = dict()
        addons[addon]["meta"] = get_meta(addon)
        addons[addon]["enabled"] = True
        
        m = "%s.models" % addon
        for app in models.get_apps():
            if m == app.__name__:
                addons[addon]["models_loaded"] = True
                break

    for addon in settings.ADDONS_DISABLED:
        addons[addon] = dict()
        addons[addon]["meta"] = get_meta(addon)
        addons[addon]["enabled"] = False
        
    context = {"addons":addons, "settings":settings }
    return render_to_response("addons.html", context,
        context_instance=RequestContext(request))
